@@ -1406,7 +1406,8 @@ CREATE TABLE cwi_test (
 
 -- add some data so that all tests have something to work with.
 INSERT INTO cwi_test
-    VALUES (1, 2),
+VALUES
+    (1, 2),
     (3, 4),
     (5, 6);
 
@@ -1473,7 +1474,8 @@ FROM
     onek;
 
 INSERT INTO onek_with_null (unique1, unique2)
-    VALUES (NULL, -1),
+VALUES
+    (NULL, -1),
     (NULL, NULL);
 
 CREATE UNIQUE INDEX onek_nulltest ON onek_with_null (unique2, unique1);
@@ -2271,7 +2273,8 @@ CREATE TABLE concur_reindex_tab4 (
 );
 
 INSERT INTO concur_reindex_tab4
-    VALUES (1),
+VALUES
+    (1),
     (1),
     (2);
 
