@@ -380,7 +380,8 @@ CREATE TEMP TABLE test_json (
 );
 
 INSERT INTO test_json
-    VALUES ('scalar', '"a scalar"'),
+VALUES
+    ('scalar', '"a scalar"'),
     ('array', '["zero", "one","two",null,"four","five", [1,2,3],{"f1":9}]'),
     ('object', '{"field1":"val1","field2":"val2","field3":null, "field4": 4, "field5": [1,2,3], "field6": {"f1":9}}');
 
