@@ -1656,7 +1656,8 @@ CREATE OR REPLACE FUNCTION insert_tt (text)
     RETURNS int
     AS $$
     INSERT INTO tt (data)
-        VALUES ($1),
+    VALUES
+        ($1),
         ($1 || $1)
     RETURNING
         f1
@@ -1676,7 +1677,8 @@ CREATE OR REPLACE FUNCTION insert_tt2 (text, text)
     RETURNS SETOF int
     AS $$
     INSERT INTO tt (data)
-        VALUES ($1),
+    VALUES
+        ($1),
         ($2)
     RETURNING
         f1
@@ -1856,7 +1858,8 @@ CREATE FUNCTION testrngfunc ()
     RETURNS SETOF record
     AS $$
     INSERT INTO rngfunc
-        VALUES (1, 2),
+    VALUES
+        (1, 2),
         (3, 4)
     RETURNING
         *;
