@@ -381,7 +381,8 @@ LANGUAGE plpgsql;
 
 -- basic before trigger
 INSERT INTO trunc_trigger_test
-    VALUES (1, 'foo', 'bar'),
+VALUES
+    (1, 'foo', 'bar'),
     (2, 'baz', 'quux');
 
 CREATE TRIGGER t
@@ -417,7 +418,8 @@ TRUNCATE trunc_trigger_log;
 
 -- same test with an after trigger
 INSERT INTO trunc_trigger_test
-    VALUES (1, 'foo', 'bar'),
+VALUES
+    (1, 'foo', 'bar'),
     (2, 'baz', 'quux');
 
 CREATE TRIGGER tt
@@ -565,11 +567,13 @@ CREATE FUNCTION tp_ins_data ()
     AS $$
 BEGIN
     INSERT INTO truncprim
-        VALUES (1),
+    VALUES
+        (1),
         (100),
         (150);
     INSERT INTO truncpart
-        VALUES (1),
+    VALUES
+        (1),
         (100),
         (150);
 END
@@ -588,10 +592,10 @@ BEGIN
         fk.a
     FROM
         truncprim pk
-    FULL JOIN truncpart fk USING (a)
-ORDER BY
-    2,
-    4;
+        FULL JOIN truncpart fk USING (a)
+    ORDER BY
+        2,
+        4;
 END
 $$;
 
