@@ -3,7 +3,6 @@
 -- Please click the button <Format>
 -- or "ctrl+F"
 ------------------------------------------
-
 SELECT
     price.col1 AS col1,
     price.col2 AS col2,
@@ -38,7 +37,7 @@ SELECT
 FROM (
     SELECT
         store.column1,
-        CAST(store.column2 AS integer) AS column2, -- inline comment
+        cast(store.column2 AS integer) AS column2, -- inline comment
         store.columnwe34r3 AS column3, -- inline comment
         store.column4_prod AS column4, -- inline comment
         store.column5_pre_prod_first AS column5, -- inline comment
@@ -53,8 +52,7 @@ FROM (
             -- SQL statement   --
             ---------------------
             library.column2,
-            library.column3 -- inline comment
-,
+            library.column3, -- inline comment
             CASE library.column4
             WHEN cheap THEN
                 digits (library.column27) || library.column28
